@@ -55,7 +55,7 @@ class SongsView(BaseView):
         self._offset = 0
         self._iter_to_clean = None
 
-        view_style  = self._view.get_generic_view().get_style_context()
+        view_style = self._view.get_generic_view().get_style_context()
         view_style.add_class('songs-list')
         view_style.remove_class('content-view')
 
@@ -92,8 +92,8 @@ class SongsView(BaseView):
             return
 
         if self.model[itr][8] != self._error_icon_name:
-           self.player.set_playlist('Songs', None, self.model, itr, 5, 11)
-           self.player.set_playing(True)
+            self.player.set_playlist('Songs', None, self.model, itr, 5, 11)
+            self.player.set_playing(True)
 
     @log
     def update_model(self, player, playlist, current_iter):
@@ -140,7 +140,6 @@ class SongsView(BaseView):
     @log
     def _add_list_renderers(self):
         list_widget = self._view.get_generic_view()
-        list_widget.set_halign(Gtk.Align.CENTER)
         cols = list_widget.get_columns()
         cells = cols[0].get_cells()
         cells[2].set_visible(False)
@@ -156,13 +155,19 @@ class SongsView(BaseView):
                                               None)
         list_widget.insert_column(column_now_playing, 0)
         title_renderer = Gtk.CellRendererText(
-            xpad=0, xalign=0.0, yalign=0.5, height=48, width=300,
+            xpad=0, xalign=0.0, yalign=0.5, height=48,
             ellipsize=Pango.EllipsizeMode.END)
 
         list_widget.add_renderer(title_renderer,
                                  self._on_list_widget_title_render, None)
         cols[0].add_attribute(title_renderer, 'text', 2)
-        self._star_handler.add_star_renderers(list_widget, cols)
+        cols[0].set_expand(True)
+
+        col = Gtk.TreeViewColumn()
+        col.set_expand(False)
+        self._star_handler.add_star_renderers(list_widget, col)
+        list_widget.append_column(col)
+
         duration_renderer = Gd.StyledTextRenderer(xpad=32, xalign=1.0)
         duration_renderer.add_class('dim-label')
         col = Gtk.TreeViewColumn()
@@ -171,7 +176,7 @@ class SongsView(BaseView):
                                self._on_list_widget_duration_render, None)
         list_widget.append_column(col)
         artist_renderer = Gd.StyledTextRenderer(
-            xpad=32, width=300, ellipsize=Pango.EllipsizeMode.END)
+            xpad=32, ellipsize=Pango.EllipsizeMode.END)
         artist_renderer.add_class('dim-label')
 
         col = Gtk.TreeViewColumn()
@@ -183,12 +188,15 @@ class SongsView(BaseView):
         list_widget.append_column(col)
 
         type_renderer = Gd.StyledTextRenderer(
-            xpad=32, width=300, ellipsize=Pango.EllipsizeMode.END)
+            xpad=32, ellipsize=Pango.EllipsizeMode.END)
         type_renderer.add_class('dim-label')
 
-        col.pack_end(type_renderer, True)
+        col = Gtk.TreeViewColumn()
+        col.set_expand(True)
+        col.pack_start(type_renderer, True)
         col.set_cell_data_func(type_renderer, self._on_list_widget_type_render,
                                None)
+        list_widget.append_column(col)
 
     def _on_list_widget_title_render(self, col, cell, model, itr, data):
         pass
